#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2019-11-02
#
# OSPFv3 plugin metrics
#
from cmk.gui.i18n import _

from cmk.gui.plugins.metrics import (
    metric_info,
    graph_info,
    perfometer_info
)


#####################################################################################################################
#
# define metrics for perfdata
#
#####################################################################################################################

metric_info['ospfv3_general_lsacount'] = {
    'title': _('LSA count'),
    'unit': 'count',
    'color': '26/a',
}
metric_info['ospfv3_general_rxnewlsas'] = {
    'title': _('receive new LSA count'),
    'unit': 'count',
    'color': '16/a',
}
metric_info['ospfv3_general_extlsacount'] = {
    'title': _('Etxternal LSA count'),
    'unit': 'count',
    'color': '16/a',
}

metric_info['ospfv3_events'] = {
    'title': _('Events'),
    'unit': 'count',
    'color': '26/a',
}
metric_info['ospfv3_lsretransqlen'] = {
    'title': _('Queue length'),
    'unit': 'count',
    'color': '16/a',
}

metric_info['ospfv3_interface_events'] = {
    'title': _('Events'),
    'unit': 'count',
    'color': '26/a',
}
metric_info['ospfv3_interface_linkscopelsacount'] = {
    'title': _('Link LSA count'),
    'unit': 'count',
    'color': '16/a',
}

metric_info['ospfv3_area_spfruns'] = {
    'title': _('SPF runs'),
    'unit': 'count',
    'color': '26/a',
}
metric_info['ospfv3_area_bdrrtcount'] = {
    'title': _('# of ABRs'),
    'unit': 'count',
    'color': '11/a',
}
metric_info['ospfv3_area_asbdrrtrcount'] = {
    'title': _('# of ASBRs'),
    'unit': 'count',
    'color': '22/a',
}
metric_info['ospfv3_area_scopelsacount'] = {
    'title': _('Area LSA count'),
    'unit': 'count',
    'color': '23/a',
}
metric_info['ospfv3_area_nssatranslatorevents'] = {
    'title': _('NSSA translator events'),
    'unit': 'count',
    'color': '11/a',
}

######################################################################################################################
#
# how to graph perdata
#
######################################################################################################################


graph_info['ospfv3_general'] = {
    'title': _('LSA count'),
    'metrics': [
        ('ospfv3_general_lsacount', 'line'),
        ('ospfv3_general_rxnewlsas', 'line'),
        ('ospfv3_general_extlsacount', 'line'),
    ],
}

graph_info['ospfv3_events'] = {
    'title': _('OSPFv3 Events'),
    'metrics': [
        ('ospfv3_events', 'area'),
    ],
}
graph_info['ospfv3_lsretransqlen'] = {
    'title': _('Link state retransmission queue length'),
    'metrics': [
        ('ospfv3_lsretransqlen', 'area'),
    ],
}
graph_info['ospfv3_interface'] = {
    'title': _('Link scope LSA count'),
    'metrics': [
        ('ospfv3_interface_linkscopelsacount', 'area'),
    ],
}
graph_info['ospfv3_area_spfruns'] = {
    'title': _('SPF runs'),
    'metrics': [
        ('ospfv3_area_spfruns', 'area'),
    ],
}
graph_info['ospfv3_area_border'] = {
    'title': _('Border router count'),
    'metrics': [
        ('ospfv3_area_bdrrtcount', 'area'),
        ('ospfv3_area_asbdrrtrcount', '-area'),
    ],
}
graph_info['ospfv3_area_scopelsacount'] = {
    'title': _('Area scope LSA count'),
    'metrics': [
        ('ospfv3_area_scopelsacount', 'area'),
    ],
}
graph_info['ospfv3_area_nssatranslatorevents'] = {
    'title': _('NSSA translator events'),
    'metrics': [
        ('ospfv3_area_nssatranslatorevents', 'area'),
    ],
}

######################################################################################################################
#
# define perf-o-meter
#
######################################################################################################################

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': ['ospfv3_general_lsacount',
                     ],
        'total': 100,
    },
    {
        'type': 'linear',
        'segments': ['ospfv3_general_extlsacount',
                     ],
        'total': 100,
    }
]))

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': ['ospfv3_events',
                     ],
        'total': 100,
    },
    {
        'type': 'linear',
        'segments': ['ospfv3_lsretransqlen',
                     ],
        'total': 100,
    }
]))

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': ['ospfv3_interface_events',
                     ],
        'total': 1000,
    },
    {
        'type': 'linear',
        'segments': ['ospfv3_interface_linkscopelsacount',
                     ],
        'total': 1000,
    }
]))

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': ['ospfv3_area_spfruns',
                     ],
        'total': 1000,
    },
    {
        'type': 'linear',
        'segments': ['ospfv3_area_scopelsacount',
                     ],
        'total': 1000,
    }
]))
